@@ -3,7 +3,7 @@
 """
 import pytest
 
-from config.run_config import mainSetup as ms, mainTearDown as mt
+from config.runConfig import mainSetup as ms, mainTearDown as mt
 
 if __name__ == '__main__':
     ms()        #测试前置
